#
# spec file for package python-suds
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15allpythons}
Name:           python-suds
Version:        1.2.0
Release:        2.1
Summary:        Lightweight SOAP client
License:        LGPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://github.com/suds-community/suds
Source:         https://files.pythonhosted.org/packages/source/s/suds/suds-%{version}.tar.gz
BuildRequires:  %{python_module devel}
# Test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module xml}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Provides:       python-suds-jurko = %{version}
Obsoletes:      python-suds-jurko < %{version}
Provides:       python-suds-community = %{version}
Obsoletes:      python-suds-community < %{version}
BuildArch:      noarch
%python_subpackages

%description
Suds is a lightweight SOAP-based web service client for Python.

Although the original suds package stopped releasing versions after
0.4, many (but not all) other open source projects moved to a
maintained fork known as "suds-jurko". This is a community fork of
that fork that is releasing packages under the main suds package name
(and suds-community for consistency until version 2.x of this
package).

%prep
%autosetup -p1 -n suds-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}/%{$python_sitelib}/suds*

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitelib}/suds
%{python_sitelib}/suds_community-%{version}-py%{python_version}.egg-info

%changelog
* Fri Dec 20 2024 Matej Cepl <mcepl@cepl.eu>
- Add %%{?sle15allpythons} call
* Tue Sep  3 2024 pgajdos@suse.com
- version update to 1.2.0
  * Remove support from before Python 3.7
  * asdict functionality to optionally recursively give suds object
  * Support process SOAP 1.2 reply
* Tue Oct 11 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.1.2
  * Restore last_sent and last_received functions
* Sat Jun  4 2022 Dirk Müller <dmueller@suse.com>
- update to 1.1.1:
  * Update for modern python except handling
  * Fix unclosed file pointer in tests.
  * Cleanup extra print statement.
  * Fix undeclared variables.
  * Don't ignore underscore prefixed attributes
  * Allow subclasses of Builder to determine if children are initialized.
  * Use usedforsecurity=False for md5() calls to make suds work on FIPS
* Sun Jan 30 2022 Rolf Krahl <rolf@rotkraut.de>
- Update outdated description, summary and URL: this is not the jurko
  fork anymore
* Mon Nov  8 2021 Dirk Müller <dmueller@suse.com>
- add six for testsuite
* Sat Nov  6 2021 Dirk Müller <dmueller@suse.com>
- update to 1.0.0:
  * python 2.x removal
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 0.8.5:
  * Add per invocation timeout
  * Ensure request headers set in options are used to fetch definitions
  * Fix pypi description format
  * Add option to disable the sorting of namespaces.
  * Add option to allow unknown message parts.
  * Fix bug introduced in 0.8.0, initialize optional arrays with empty lists
  * Add WSSE password digest and nonce encoding type (@ovnicraft)
  * Pass header while requesting a WSDL (@guifran001)
* Wed May 27 2020 Jason Craig <os-dev@jacraig.com>
- Change %%{py_ver} to %%{python_version} to fix build.
- Mark license with %%license instead of %%doc.
* Thu Jun 22 2017 alarrosa@suse.com
- singlespec version of python-suds-jurko
- Remove openstack-macros and openstack-suse-macros from BuildRequires.
  The package builds fine without them.
- Use fdupes on installed files.
* Tue Oct  4 2016 rolf@rotkraut.de
- Add suds-insecure-cache-tempdir.patch: CVE-2013-2217 (bsc#827568)
* Thu Sep  8 2016 tbechtold@suse.com
- Add missing openstack-macros BuildRequires
- Use pypi.io as Source url
* Wed Oct 14 2015 tbechtold@suse.com
- Don't install tests/ dir into site-packages.
* Wed Jul 29 2015 tbechtold@suse.com
- Unify spec file. Use fedora compatible files macros
* Sat May 16 2015 dmueller@suse.com
- Initial package (0.6)
